from pydantic import BaseModel, Field

class IncomeStatement(BaseModel):
    date: str = Field(..., description="The date of the income statement")
    symbol: str = Field(..., description="The symbol of the income statement")
    reportedCurrency: str = Field(..., description="The reported currency of the income statement")
    cik: str = Field(..., description="The cik of the income statement")
    filingDate: str = Field(..., description="The filing date of the income statement")
    acceptedDate: str = Field(..., description="The accepted date of the income statement")
    fiscalYear: str = Field(..., description="The fiscal year of the income statement")
    period: str = Field(..., description="The period of the income statement")
    revenue: float = Field(..., description="The revenue of the income statement")
    costOfRevenue: float = Field(..., description="The cost of revenue of the income statement")
    grossProfit: float = Field(..., description="The gross profit of the income statement")
    researchAndDevelopmentExpenses: float = Field(..., description="The research and development expenses of the income statement")
    generalAndAdministrativeExpenses: float = Field(..., description="The general and administrative expenses of the income statement")
    sellingAndMarketingExpenses: float = Field(..., description="The selling and marketing expenses of the income statement")
    sellingGeneralAndAdministrativeExpenses: float = Field(..., description="The selling general and administrative expenses of the income statement")
    otherExpenses: float = Field(..., description="The other expenses of the income statement")
    operatingExpenses: float = Field(..., description="The operating expenses of the income statement")
    costAndExpenses: float = Field(..., description="The cost and expenses of the income statement")
    netInterestIncome: float = Field(..., description="The net interest income of the income statement")
    interestIncome: float = Field(..., description="The interest income of the income statement")
    interestExpense: float = Field(..., description="The interest expense of the income statement")
    depreciationAndAmortization: float = Field(..., description="The depreciation and amortization of the income statement")
    ebitda: float = Field(..., description="The ebitda of the income statement")
    ebit: float = Field(..., description="The ebit of the income statement")
    nonOperatingIncomeExcludingInterest: float = Field(..., description="The non operating income excluding interest of the income statement")
    operatingIncome: float = Field(..., description="The operating income of the income statement")
    totalOtherIncomeExpensesNet: float = Field(..., description="The total other income expenses net of the income statement")
    incomeBeforeTax: float = Field(..., description="The income before tax of the income statement")
    incomeTaxExpense: float = Field(..., description="The income tax expense of the income statement")
    netIncomeFromContinuingOperations: float = Field(..., description="The net income from continuing operations of the income statement")
    netIncomeFromDiscontinuedOperations: float = Field(..., description="The net income from discontinued operations of the income statement")
    otherAdjustmentsToNetIncome: float = Field(..., description="The other adjustments to net income of the income statement")
    netIncome: float = Field(..., description="The net income of the income statement")
    netIncomeDeductions: float = Field(..., description="The net income deductions of the income statement")
    bottomLineNetIncome: float = Field(..., description="The bottom line net income of the income statement")
    eps: float = Field(..., description="The eps of the income statement")
    epsDiluted: float = Field(..., description="The eps diluted of the income statement")
    weightedAverageShsOut: float = Field(..., description="The weighted average shs out of the income statement")
    weightedAverageShsOutDil: float = Field(..., description="The weighted average shs out diluted of the income statement")

class BalanceSheetStatement(BaseModel):
    date: str = Field(..., description="The date of the balance sheet statement")
    symbol: str = Field(..., description="The symbol of the balance sheet statement")
    reportedCurrency: str = Field(..., description="The reported currency of the balance sheet statement")
    cik: str = Field(..., description="The cik of the balance sheet statement")
    filingDate: str = Field(..., description="The filing date of the balance sheet statement")
    acceptedDate: str = Field(..., description="The accepted date of the balance sheet statement")
    fiscalYear: str = Field(..., description="The fiscal year of the balance sheet statement")
    period: str = Field(..., description="The period of the balance sheet statement")
    cashAndCashEquivalents: float = Field(..., description="The cash and cash equivalents of the balance sheet statement")
    shortTermInvestments: float = Field(..., description="The short term investments of the balance sheet statement")
    cashAndShortTermInvestments: float = Field(..., description="The cash and short term investments of the balance sheet statement")
    netReceivables: float = Field(..., description="The net receivables of the balance sheet statement")
    accountsReceivables: float = Field(..., description="The accounts receivables of the balance sheet statement")
    otherReceivables: float = Field(..., description="The other receivables of the balance sheet statement")
    inventory: float = Field(..., description="The inventory of the balance sheet statement")
    prepaids: float = Field(..., description="The prepaids of the balance sheet statement")
    otherCurrentAssets: float = Field(..., description="The other current assets of the balance sheet statement")
    totalCurrentAssets: float = Field(..., description="The total current assets of the balance sheet statement")
    propertyPlantEquipmentNet: float = Field(..., description="The property plant and equipment net of the balance sheet statement")
    goodwill: float = Field(..., description="The goodwill of the balance sheet statement")
    intangibleAssets: float = Field(..., description="The intangible assets of the balance sheet statement")
    goodwillAndIntangibleAssets: float = Field(..., description="The goodwill and intangible assets of the balance sheet statement")
    longTermInvestments: float = Field(..., description="The long term investments of the balance sheet statement")
    taxAssets: float = Field(..., description="The tax assets of the balance sheet statement")
    otherNonCurrentAssets: float = Field(..., description="The other non current assets of the balance sheet statement")
    totalNonCurrentAssets: float = Field(..., description="The total non current assets of the balance sheet statement")
    otherAssets: float = Field(..., description="The other assets of the balance sheet statement")
    totalAssets: float = Field(..., description="The total assets of the balance sheet statement")
    totalPayables: float = Field(..., description="The total payables of the balance sheet statement")
    accountPayables: float = Field(..., description="The account payables of the balance sheet statement")
    otherPayables: float = Field(..., description="The other payables of the balance sheet statement")
    accruedExpenses: float = Field(..., description="The accrued expenses of the balance sheet statement")
    shortTermDebt: float = Field(..., description="The short term debt of the balance sheet statement")
    capitalLeaseObligationsCurrent: float = Field(..., description="The capital lease obligations current of the balance sheet statement")
    taxPayables: float = Field(..., description="The tax payables of the balance sheet statement")
    deferredRevenue: float = Field(..., description="The deferred revenue of the balance sheet statement")
    otherCurrentLiabilities: float = Field(..., description="The other current liabilities of the balance sheet statement")
    totalCurrentLiabilities: float = Field(..., description="The total current liabilities of the balance sheet statement")
    longTermDebt: float = Field(..., description="The long term debt of the balance sheet statement")
    deferredRevenueNonCurrent: float = Field(..., description="The deferred revenue non current of the balance sheet statement")
    deferredTaxLiabilitiesNonCurrent: float = Field(..., description="The deferred tax liabilities non current of the balance sheet statement")
    otherNonCurrentLiabilities: float = Field(..., description="The other non current liabilities of the balance sheet statement")
    totalNonCurrentLiabilities: float = Field(..., description="The total non current liabilities of the balance sheet statement")
    otherLiabilities: float = Field(..., description="The other liabilities of the balance sheet statement")
    capitalLeaseObligations: float = Field(..., description="The capital lease obligations of the balance sheet statement")
    totalLiabilities: float = Field(..., description="The total liabilities of the balance sheet statement")
    treasuryStock: float = Field(..., description="The treasury stock of the balance sheet statement")
    preferredStock: float = Field(..., description="The preferred stock of the balance sheet statement")
    commonStock: float = Field(..., description="The common stock of the balance sheet statement")
    retainedEarnings: float = Field(..., description="The retained earnings of the balance sheet statement")
    additionalPaidInCapital: float = Field(..., description="The additional paid in capital of the balance sheet statement")
    accumulatedOtherComprehensiveIncomeLoss: float = Field(..., description="The accumulated other comprehensive income loss of the balance sheet statement")
    otherTotalStockholdersEquity: float = Field(..., description="The other total stockholders equity of the balance sheet statement")
    totalStockholdersEquity: float = Field(..., description="The total stockholders equity of the balance sheet statement")
    totalEquity: float = Field(..., description="The total equity of the balance sheet statement")
    minorityInterest: float = Field(..., description="The minority interest of the balance sheet statement")
    totalLiabilitiesAndTotalEquity: float = Field(..., description="The total liabilities and total equity of the balance sheet statement")
    totalInvestments: float = Field(..., description="The total investments of the balance sheet statement")
    totalDebt: float = Field(..., description="The total debt of the balance sheet statement")
    netDebt: float = Field(..., description="The net debt of the balance sheet statement")
    
class CashFlowStatement(BaseModel):
    date: str = Field(..., description="The date of the cash flow statement")
    symbol: str = Field(..., description="The symbol of the cash flow statement")
    reportedCurrency: str = Field(..., description="The reported currency of the cash flow statement")
    cik: str = Field(..., description="The cik of the cash flow statement")
    filingDate: str = Field(..., description="The filing date of the cash flow statement")
    acceptedDate: str = Field(..., description="The accepted date of the cash flow statement")
    fiscalYear: str = Field(..., description="The fiscal year of the cash flow statement")
    period: str = Field(..., description="The period of the cash flow statement")
    netIncome: float = Field(..., description="The net income of the cash flow statement")
    depreciationAndAmortization: float = Field(..., description="The depreciation and amortization of the cash flow statement")
    deferredIncomeTax: float = Field(..., description="The deferred income tax of the cash flow statement")
    stockBasedCompensation: float = Field(..., description="The stock based compensation of the cash flow statement")
    changeInWorkingCapital: float = Field(..., description="The change in working capital of the cash flow statement")
    accountsReceivables: float = Field(..., description="The accounts receivables of the cash flow statement")
    inventory: float = Field(..., description="The inventory of the cash flow statement")
    accountsPayables: float = Field(..., description="The accounts payables of the cash flow statement")
    otherWorkingCapital: float = Field(..., description="The other working capital of the cash flow statement")
    otherNonCashItems: float = Field(..., description="The other non cash items of the cash flow statement")
    netCashProvidedByOperatingActivities: float = Field(..., description="The net cash provided by operating activities of the cash flow statement")
    investmentsInPropertyPlantAndEquipment: float = Field(..., description="The investments in property plant and equipment of the cash flow statement")
    acquisitionsNet: float = Field(..., description="The acquisitions net of the cash flow statement")
    purchasesOfInvestments: float = Field(..., description="The purchases of investments of the cash flow statement")
    salesMaturitiesOfInvestments: float = Field(..., description="The sales maturities of investments of the cash flow statement")
    otherInvestingActivities: float = Field(..., description="The other investing activities of the cash flow statement")
    netCashProvidedByInvestingActivities: float = Field(..., description="The net cash provided by investing activities of the cash flow statement")
    netDebtIssuance: float = Field(..., description="The net debt issuance of the cash flow statement")
    longTermNetDebtIssuance: float = Field(..., description="The long term net debt issuance of the cash flow statement")
    shortTermNetDebtIssuance: float = Field(..., description="The short term net debt issuance of the cash flow statement")
    netStockIssuance: float = Field(..., description="The net stock issuance of the cash flow statement")
    netCommonStockIssuance: float = Field(..., description="The net common stock issuance of the cash flow statement")
    commonStockIssuance: float = Field(..., description="The common stock issuance of the cash flow statement")
    commonStockRepurchased: float = Field(..., description="The common stock repurchased of the cash flow statement")
    netPreferredStockIssuance: float = Field(..., description="The net preferred stock issuance of the cash flow statement")
    netDividendsPaid: float = Field(..., description="The net dividends paid of the cash flow statement")
    commonDividendsPaid: float = Field(..., description="The common dividends paid of the cash flow statement")
    preferredDividendsPaid: float = Field(..., description="The preferred dividends paid of the cash flow statement")
    otherFinancingActivities: float = Field(..., description="The other financing activities of the cash flow statement")
    netCashProvidedByFinancingActivities: float = Field(..., description="The net cash provided by financing activities of the cash flow statement")
    effectOfForexChangesOnCash: float = Field(..., description="The effect of forex changes on cash of the cash flow statement")
    netChangeInCash: float = Field(..., description="The net change in cash of the cash flow statement")
    cashAtEndOfPeriod: float = Field(..., description="The cash at the end of period of the cash flow statement")
    cashAtBeginningOfPeriod: float = Field(..., description="The cash at the beginning of period of the cash flow statement")
    operatingCashFlow: float = Field(..., description="The operating cash flow of the cash flow statement")
    capitalExpenditure: float = Field(..., description="The capital expenditure of the cash flow statement")
    freeCashFlow: float = Field(..., description="The free cash flow of the cash flow statement")
    incomeTaxesPaid: float = Field(..., description="The income taxes paid of the cash flow statement")
    interestPaid: float = Field(..., description="The interest paid of the cash flow statement")

class IncomeStatementGrowth(BaseModel):
    symbol: str = Field(..., description="The symbol of the income statement growth")
    date: str = Field(..., description="The date of the income statement growth")
    fiscalYear: str = Field(..., description="The fiscal year of the income statement growth")
    period: str = Field(..., description="The period of the income statement growth")
    reportedCurrency: str = Field(..., description="The reported currency of the income statement growth")
    growthRevenue: float = Field(..., description="The growth revenue of the income statement growth")
    growthCostOfRevenue: float = Field(..., description="The growth cost of revenue of the income statement growth")
    growthGrossProfit: float = Field(..., description="The growth gross profit of the income statement growth")
    growthGrossProfitRatio: float = Field(..., description="The growth gross profit ratio of the income statement growth")
    growthResearchAndDevelopmentExpenses: float = Field(..., description="The growth research and development expenses of the income statement growth")
    growthGeneralAndAdministrativeExpenses: float = Field(..., description="The growth general and administrative expenses of the income statement growth")
    growthSellingAndMarketingExpenses: float = Field(..., description="The growth selling and marketing expenses of the income statement growth")
    growthOtherExpenses: float = Field(..., description="The growth other expenses of the income statement growth")
    growthOperatingExpenses: float = Field(..., description="The growth operating expenses of the income statement growth")
    growthCostAndExpenses: float = Field(..., description="The growth cost and expenses of the income statement growth")
    growthInterestIncome: float = Field(..., description="The growth interest income of the income statement growth")
    growthInterestExpense: float = Field(..., description="The growth interest expense of the income statement growth")
    growthDepreciationAndAmortization: float = Field(..., description="The growth depreciation and amortization of the income statement growth")
    growthEBITDA: float = Field(..., description="The growth ebitda of the income statement growth")
    growthOperatingIncome: float = Field(..., description="The growth operating income of the income statement growth")
    growthIncomeBeforeTax: float = Field(..., description="The growth income before tax of the income statement growth")
    growthIncomeTaxExpense: float = Field(..., description="The growth income tax expense of the income statement growth")
    growthNetIncome: float = Field(..., description="The growth net income of the income statement growth")
    growthEPS: float = Field(..., description="The growth eps of the income statement growth")
    growthEPSDiluted: float = Field(..., description="The growth eps diluted of the income statement growth")
    growthWeightedAverageShsOut: float = Field(..., description="The growth weighted average shs out of the income statement growth")
    growthWeightedAverageShsOutDil: float = Field(..., description="The growth weighted average shs out diluted of the income statement growth")
    growthEBIT: float = Field(..., description="The growth ebit of the income statement growth")
    growthNonOperatingIncomeExcludingInterest: float = Field(..., description="The growth non operating income excluding interest of the income statement growth")
    growthNetInterestIncome: float = Field(..., description="The growth net interest income of the income statement growth")
    growthTotalOtherIncomeExpensesNet: float = Field(..., description="The growth total other income expenses net of the income statement growth")
    growthNetIncomeFromContinuingOperations: float = Field(..., description="The growth net income from continuing operations of the income statement growth")
    growthOtherAdjustmentsToNetIncome: float = Field(..., description="The growth other adjustments to net income of the income statement growth")
    growthNetIncomeDeductions: float = Field(..., description="The growth net income deductions of the income statement growth")

class BalanceSheetStatementGrowth(BaseModel):
    symbol: str = Field(..., description="The symbol of the balance sheet statement growth")
    date: str = Field(..., description="The date of the balance sheet statement growth")
    fiscalYear: str = Field(..., description="The fiscal year of the balance sheet statement growth")
    period: str = Field(..., description="The period of the balance sheet statement growth")
    reportedCurrency: str = Field(..., description="The reported currency of the balance sheet statement growth")
    growthCashAndCashEquivalents: float = Field(..., description="The growth cash and cash equivalents of the balance sheet statement growth")
    growthShortTermInvestments: float = Field(..., description="The growth short term investments of the balance sheet statement growth")
    growthCashAndShortTermInvestments: float = Field(..., description="The growth cash and short term investments of the balance sheet statement growth")
    growthNetReceivables: float = Field(..., description="The growth net receivables of the balance sheet statement growth")
    growthInventory: float = Field(..., description="The growth inventory of the balance sheet statement growth")
    growthOtherCurrentAssets: float = Field(..., description="The growth other current assets of the balance sheet statement growth")
    growthTotalCurrentAssets: float = Field(..., description="The growth total current assets of the balance sheet statement growth")
    growthPropertyPlantEquipmentNet: float = Field(..., description="The growth property plant and equipment net of the balance sheet statement growth")
    growthGoodwill: float = Field(..., description="The growth goodwill of the balance sheet statement growth")
    growthIntangibleAssets: float = Field(..., description="The growth intangible assets of the balance sheet statement growth")
    growthGoodwillAndIntangibleAssets: float = Field(..., description="The growth goodwill and intangible assets of the balance sheet statement growth")
    growthLongTermInvestments: float = Field(..., description="The growth long term investments of the balance sheet statement growth")
    growthTaxAssets: float = Field(..., description="The growth tax assets of the balance sheet statement growth")
    growthOtherNonCurrentAssets: float = Field(..., description="The growth other non current assets of the balance sheet statement growth")
    growthTotalNonCurrentAssets: float = Field(..., description="The growth total non current assets of the balance sheet statement growth")
    growthOtherAssets: float = Field(..., description="The growth other assets of the balance sheet statement growth")
    growthTotalAssets: float = Field(..., description="The growth total assets of the balance sheet statement growth")
    growthAccountPayables: float = Field(..., description="The growth account payables of the balance sheet statement growth")
    growthShortTermDebt: float = Field(..., description="The growth short term debt of the balance sheet statement growth")
    growthTaxPayables: float = Field(..., description="The growth tax payables of the balance sheet statement growth")
    growthDeferredRevenue: float = Field(..., description="The growth deferred revenue of the balance sheet statement growth")
    growthOtherCurrentLiabilities: float = Field(..., description="The growth other current liabilities of the balance sheet statement growth")
    growthTotalCurrentLiabilities: float = Field(..., description="The growth total current liabilities of the balance sheet statement growth")
    growthLongTermDebt: float = Field(..., description="The growth long term debt of the balance sheet statement growth")
    growthDeferredRevenueNonCurrent: float = Field(..., description="The growth deferred revenue non current of the balance sheet statement growth")
    growthDeferredTaxLiabilitiesNonCurrent: float = Field(..., description="The growth deferred tax liabilities non current of the balance sheet statement growth")
    growthOtherNonCurrentLiabilities: float = Field(..., description="The growth other non current liabilities of the balance sheet statement growth")
    growthTotalNonCurrentLiabilities: float = Field(..., description="The growth total non current liabilities of the balance sheet statement growth")
    growthOtherLiabilities: float = Field(..., description="The growth other liabilities of the balance sheet statement growth")
    growthTotalLiabilities: float = Field(..., description="The growth total liabilities of the balance sheet statement growth")
    growthPreferredStock: float = Field(..., description="The growth preferred stock of the balance sheet statement growth")
    growthCommonStock: float = Field(..., description="The growth common stock of the balance sheet statement growth")
    growthRetainedEarnings: float = Field(..., description="The growth retained earnings of the balance sheet statement growth")
    growthAccumulatedOtherComprehensiveIncomeLoss: float = Field(..., description="The growth accumulated other comprehensive income loss of the balance sheet statement growth")
    growthOthertotalStockholdersEquity: float = Field(..., description="The growth other total stockholders equity of the balance sheet statement growth")
    growthTotalStockholdersEquity: float = Field(..., description="The growth total stockholders equity of the balance sheet statement growth")
    growthMinorityInterest: float = Field(..., description="The growth minority interest of the balance sheet statement growth")
    growthTotalEquity: float = Field(..., description="The growth total equity of the balance sheet statement growth")
    growthTotalLiabilitiesAndStockholdersEquity: float = Field(..., description="The growth total liabilities and stockholders equity of the balance sheet statement growth")
    growthTotalInvestments: float = Field(..., description="The growth total investments of the balance sheet statement growth")
    growthTotalDebt: float = Field(..., description="The growth total debt of the balance sheet statement growth")
    growthNetDebt: float = Field(..., description="The growth net debt of the balance sheet statement growth")
    growthAccountsReceivables: float = Field(..., description="The growth accounts receivables of the balance sheet statement growth")
    growthOtherReceivables: float = Field(..., description="The growth other receivables of the balance sheet statement growth")
    growthPrepaids: float = Field(..., description="The growth prepaids of the balance sheet statement growth")
    growthTotalPayables: float = Field(..., description="The growth total payables of the balance sheet statement growth")
    growthOtherPayables: float = Field(..., description="The growth other payables of the balance sheet statement growth")
    growthAccruedExpenses: float = Field(..., description="The growth accrued expenses of the balance sheet statement growth")
    growthCapitalLeaseObligationsCurrent: float = Field(..., description="The growth capital lease obligations current of the balance sheet statement growth")
    growthAdditionalPaidInCapital: float = Field(..., description="The growth additional paid in capital of the balance sheet statement growth")
    growthTreasuryStock: float = Field(..., description="The growth treasury stock of the balance sheet statement growth")

class CashFlowStatementGrowth(BaseModel):
    symbol: str = Field(..., description="The symbol of the cash flow statement growth")
    date: str = Field(..., description="The date of the cash flow statement growth")
    fiscalYear: str = Field(..., description="The fiscal year of the cash flow statement growth")
    period: str = Field(..., description="The period of the cash flow statement growth")
    reportedCurrency: str = Field(..., description="The reported currency of the cash flow statement growth")
    growthNetIncome: float = Field(..., description="The growth net income of the cash flow statement growth")
    growthDepreciationAndAmortization: float = Field(..., description="The growth depreciation and amortization of the cash flow statement growth")
    growthDeferredIncomeTax: float = Field(..., description="The growth deferred income tax of the cash flow statement growth")
    growthStockBasedCompensation: float = Field(..., description="The growth stock based compensation of the cash flow statement growth")
    growthChangeInWorkingCapital: float = Field(..., description="The growth change in working capital of the cash flow statement growth")
    growthAccountsReceivables: float = Field(..., description="The growth accounts receivables of the cash flow statement growth")
    growthInventory: float = Field(..., description="The growth inventory of the cash flow statement growth")
    growthAccountsPayables: float = Field(..., description="The growth accounts payables of the cash flow statement growth")
    growthOtherWorkingCapital: float = Field(..., description="The growth other working capital of the cash flow statement growth")
    growthOtherNonCashItems: float = Field(..., description="The growth other non cash items of the cash flow statement growth")
    growthNetCashProvidedByOperatingActivites: float = Field(..., description="The growth net cash provided by operating activites of the cash flow statement growth")
    growthInvestmentsInPropertyPlantAndEquipment: float = Field(..., description="The growth investments in property plant and equipment of the cash flow statement growth")
    growthAcquisitionsNet: float = Field(..., description="The growth acquisitions net of the cash flow statement growth")
    growthPurchasesOfInvestments: float = Field(..., description="The growth purchases of investments of the cash flow statement growth")
    growthSalesMaturitiesOfInvestments: float = Field(..., description="The growth sales maturities of investments of the cash flow statement growth")
    growthOtherInvestingActivites: float = Field(..., description="The growth other investing activites of the cash flow statement growth")
    growthNetCashUsedForInvestingActivites: float = Field(..., description="The growth net cash used for investing activites of the cash flow statement growth")
    growthDebtRepayment: float = Field(..., description="The growth debt repayment of the cash flow statement growth")
    growthCommonStockIssued: float = Field(..., description="The growth common stock issued of the cash flow statement growth")
    growthCommonStockRepurchased: float = Field(..., description="The growth common stock repurchased of the cash flow statement growth")
    growthDividendsPaid: float = Field(..., description="The growth dividends paid of the cash flow statement growth")
    growthOtherFinancingActivites: float = Field(..., description="The growth other financing activites of the cash flow statement growth")
    growthNetCashUsedProvidedByFinancingActivities: float = Field(..., description="The growth net cash used provided by financing activities of the cash flow statement growth")
    growthEffectOfForexChangesOnCash: float = Field(..., description="The growth effect of forex changes on cash of the cash flow statement growth")
    growthNetChangeInCash: float = Field(..., description="The growth net change in cash of the cash flow statement growth")
    growthCashAtEndOfPeriod: float = Field(..., description="The growth cash at end of period of the cash flow statement growth")
    growthCashAtBeginningOfPeriod: float = Field(..., description="The growth cash at beginning of period of the cash flow statement growth")
    growthOperatingCashFlow: float = Field(..., description="The growth operating cash flow of the cash flow statement growth")
    growthCapitalExpenditure: float = Field(..., description="The growth capital expenditure of the cash flow statement growth")
    growthFreeCashFlow: float = Field(..., description="The growth free cash flow of the cash flow statement growth")
    growthNetDebtIssuance: float = Field(..., description="The growth net debt issuance of the cash flow statement growth")
    growthLongTermNetDebtIssuance: float = Field(..., description="The growth long term net debt issuance of the cash flow statement growth")
    growthShortTermNetDebtIssuance: float = Field(..., description="The growth short term net debt issuance of the cash flow statement growth")
    growthNetStockIssuance: float = Field(..., description="The growth net stock issuance of the cash flow statement growth")
    growthPreferredDividendsPaid: float = Field(..., description="The growth preferred dividends paid of the cash flow statement growth")
    growthIncomeTaxesPaid: float = Field(..., description="The growth income taxes paid of the cash flow statement growth")
    growthInterestPaid: float = Field(..., description="The growth interest paid of the cash flow statement growth")

class FinancialGrowth(BaseModel):
    symbol: str = Field(..., description="The symbol of the financial growth")
    date: str = Field(..., description="The date of the financial growth")
    fiscalYear: str = Field(..., description="The fiscal year of the financial growth")
    period: str = Field(..., description="The period of the financial growth")
    reportedCurrency: str = Field(..., description="The reported currency of the financial growth")
    revenueGrowth: float = Field(..., description="The revenue growth of the financial growth")
    grossProfitGrowth: float = Field(..., description="The gross profit growth of the financial growth")
    ebitgrowth: float = Field(..., description="The ebit growth of the financial growth")
    operatingIncomeGrowth: float = Field(..., description="The operating income growth of the financial growth")
    netIncomeGrowth: float = Field(..., description="The net income growth of the financial growth")
    epsgrowth: float = Field(..., description="The eps growth of the financial growth")
    epsdilutedGrowth: float = Field(..., description="The eps diluted growth of the financial growth")
    weightedAverageSharesGrowth: float = Field(..., description="The weighted average shares growth of the financial growth")
    weightedAverageSharesDilutedGrowth: float = Field(..., description="The weighted average shares diluted growth of the financial growth")
    dividendsPerShareGrowth: float = Field(..., description="The dividends per share growth of the financial growth")
    operatingCashFlowGrowth: float = Field(..., description="The operating cash flow growth of the financial growth")
    receivablesGrowth: float = Field(..., description="The receivables growth of the financial growth")
    inventoryGrowth: float = Field(..., description="The inventory growth of the financial growth")
    assetGrowth: float = Field(..., description="The asset growth of the financial growth")
    bookValueperShareGrowth: float = Field(..., description="The book value per share growth of the financial growth")
    debtGrowth: float = Field(..., description="The debt growth of the financial growth")
    rdexpenseGrowth: float = Field(..., description="The rd expense growth of the financial growth")
    sgaexpensesGrowth: float = Field(..., description="The sga expenses growth of the financial growth")
    freeCashFlowGrowth: float = Field(..., description="The free cash flow growth of the financial growth")
    tenYRevenueGrowthPerShare: float = Field(..., description="The 10 year revenue growth per share of the financial growth")
    fiveYRevenueGrowthPerShare: float = Field(..., description="The 5 year revenue growth per share of the financial growth")
    threeYRevenueGrowthPerShare: float = Field(..., description="The 3 year revenue growth per share of the financial growth")
    tenYOperatingCFGrowthPerShare: float = Field(..., description="The 10 year operating cash flow growth per share of the financial growth")
    fiveYOperatingCFGrowthPerShare: float = Field(..., description="The 5 year operating cash flow growth per share of the financial growth")
    threeYOperatingCFGrowthPerShare: float = Field(..., description="The 3 year operating cash flow growth per share of the financial growth")
    tenYNetIncomeGrowthPerShare: float = Field(..., description="The 10 year net income growth per share of the financial growth")
    fiveYNetIncomeGrowthPerShare: float = Field(..., description="The 5 year net income growth per share of the financial growth")
    threeYNetIncomeGrowthPerShare: float = Field(..., description="The 3 year net income growth per share of the financial growth")
    tenYShareholdersEquityGrowthPerShare: float = Field(..., description="The 10 year shareholders equity growth per share of the financial growth")
    fiveYShareholdersEquityGrowthPerShare: float = Field(..., description="The 5 year shareholders equity growth per share of the financial growth")
    threeYShareholdersEquityGrowthPerShare: float = Field(..., description="The 3 year shareholders equity growth per share of the financial growth")
    tenYDividendperShareGrowthPerShare: float = Field(..., description="The 10 year dividend per share growth per share of the financial growth")
    fiveYDividendperShareGrowthPerShare: float = Field(..., description="The 5 year dividend per share growth per share of the financial growth")
    threeYDividendperShareGrowthPerShare: float = Field(..., description="The 3 year dividend per share growth per share of the financial growth")
    ebitdaGrowth: float | None = Field(None, description="The ebitda growth of the financial growth")
    growthCapitalExpenditure: float | None = Field(None, description="The growth capital expenditure of the financial growth")
    tenYBottomLineNetIncomeGrowthPerShare: float | None = Field(None, description="The 10 year bottom line net income growth per share of the financial growth")
    fiveYBottomLineNetIncomeGrowthPerShare: float | None = Field(None, description="The 5 year bottom line net income growth per share of the financial growth")
    threeYBottomLineNetIncomeGrowthPerShare: float | None = Field(None, description="The 3 year bottom line net income growth per share of the financial growth")

class KeyMetrics(BaseModel):
    symbol: str = Field(..., description="The symbol of the key metrics")
    date: str = Field(..., description="The date of the key metrics")
    fiscalYear: str = Field(..., description="The fiscal year of the key metrics")
    period: str = Field(..., description="The period of the key metrics")
    reportedCurrency: str = Field(..., description="The reported currency of the key metrics")
    marketCap: float = Field(..., description="The market cap of the key metrics")
    enterpriseValue: float = Field(..., description="The enterprise value of the key metrics")
    evToSales: float = Field(..., description="The ev to sales of the key metrics")
    evToOperatingCashFlow: float = Field(..., description="The ev to operating cash flow of the key metrics")
    evToFreeCashFlow: float = Field(..., description="The ev to free cash flow of the key metrics")
    evToEBITDA: float = Field(..., description="The ev to ebitda of the key metrics")
    netDebtToEBITDA: float = Field(..., description="The net debt to ebitda of the key metrics")
    currentRatio: float = Field(..., description="The current ratio of the key metrics")
    incomeQuality: float = Field(..., description="The income quality of the key metrics")
    grahamNumber: float = Field(..., description="The graham number of the key metrics")
    grahamNetNet: float = Field(..., description="The graham net net of the key metrics")
    taxBurden: float = Field(..., description="The tax burden of the key metrics")
    interestBurden: float = Field(..., description="The interest burden of the key metrics")
    workingCapital: float = Field(..., description="The working capital of the key metrics")
    investedCapital: float = Field(..., description="The invested capital of the key metrics")
    returnOnAssets: float = Field(..., description="The return on assets of the key metrics")
    operatingReturnOnAssets: float = Field(..., description="The operating return on assets of the key metrics")
    returnOnTangibleAssets: float = Field(..., description="The return on tangible assets of the key metrics")
    returnOnEquity: float = Field(..., description="The return on equity of the key metrics")
    returnOnInvestedCapital: float = Field(..., description="The return on invested capital of the key metrics")
    returnOnCapitalEmployed: float = Field(..., description="The return on capital employed of the key metrics")
    earningsYield: float = Field(..., description="The earnings yield of the key metrics")
    freeCashFlowYield: float = Field(..., description="The free cash flow yield of the key metrics")
    capexToOperatingCashFlow: float = Field(..., description="The capex to operating cash flow of the key metrics")
    capexToDepreciation: float = Field(..., description="The capex to depreciation of the key metrics")
    capexToRevenue: float = Field(..., description="The capex to revenue of the key metrics")
    salesGeneralAndAdministrativeToRevenue: float = Field(..., description="The sales general and administrative to revenue of the key metrics")
    researchAndDevelopementToRevenue: float = Field(..., description="The research and development to revenue of the key metrics")
    stockBasedCompensationToRevenue: float = Field(..., description="The stock based compensation to revenue of the key metrics")
    intangiblesToTotalAssets: float = Field(..., description="The intangibles to total assets of the key metrics")
    averageReceivables: float = Field(..., description="The average receivables of the key metrics")
    averagePayables: float = Field(..., description="The average payables of the key metrics")
    averageInventory: float = Field(..., description="The average inventory of the key metrics")
    daysOfSalesOutstanding: float = Field(..., description="The days of sales outstanding of the key metrics")
    daysOfPayablesOutstanding: float = Field(..., description="The days of payables outstanding of the key metrics")
    daysOfInventoryOutstanding: float = Field(..., description="The days of inventory outstanding of the key metrics")
    operatingCycle: float = Field(..., description="The operating cycle of the key metrics")
    cashConversionCycle: float = Field(..., description="The cash conversion cycle of the key metrics")
    freeCashFlowToEquity: float = Field(..., description="The free cash flow to equity of the key metrics")
    freeCashFlowToFirm: float = Field(..., description="The free cash flow to firm of the key metrics")
    tangibleAssetValue: float = Field(..., description="The tangible asset value of the key metrics")
    netCurrentAssetValue: float = Field(..., description="The net current asset value of the key metrics")
    
class KeyMetricsTTM(BaseModel):
    symbol: str = Field(..., description="The symbol of the key metrics ttm")
    marketCap: float = Field(..., description="The market cap of the key metrics ttm")
    enterpriseValueTTM: float = Field(..., description="The enterprise value ttm of the key metrics ttm")
    evToSalesTTM: float = Field(..., description="The ev to sales ttm of the key metrics ttm")
    evToOperatingCashFlowTTM: float = Field(..., description="The ev to operating cash flow ttm of the key metrics ttm")
    evToFreeCashFlowTTM: float = Field(..., description="The ev to free cash flow ttm of the key metrics ttm")
    evToEBITDATTM: float = Field(..., description="The ev to ebitda ttm of the key metrics ttm")
    netDebtToEBITDATTM: float = Field(..., description="The net debt to ebitda ttm of the key metrics ttm")
    currentRatioTTM: float = Field(..., description="The current ratio ttm of the key metrics ttm")
    incomeQualityTTM: float = Field(..., description="The income quality ttm of the key metrics ttm")
    grahamNumberTTM: float = Field(..., description="The graham number ttm of the key metrics ttm")
    grahamNetNetTTM: float = Field(..., description="The graham net net ttm of the key metrics ttm")
    taxBurdenTTM: float = Field(..., description="The tax burden ttm of the key metrics ttm")
    interestBurdenTTM: float = Field(..., description="The interest burden ttm of the key metrics ttm")
    workingCapitalTTM: float = Field(..., description="The working capital ttm of the key metrics ttm")
    investedCapitalTTM: float = Field(..., description="The invested capital ttm of the key metrics ttm")
    returnOnAssetsTTM: float = Field(..., description="The return on assets ttm of the key metrics ttm")
    operatingReturnOnAssetsTTM: float = Field(..., description="The operating return on assets ttm of the key metrics ttm")
    returnOnTangibleAssetsTTM: float = Field(..., description="The return on tangible assets ttm of the key metrics ttm")
    returnOnEquityTTM: float = Field(..., description="The return on equity ttm of the key metrics ttm")
    returnOnInvestedCapitalTTM: float = Field(..., description="The return on invested capital ttm of the key metrics ttm")
    returnOnCapitalEmployedTTM: float = Field(..., description="The return on capital employed ttm of the key metrics ttm")
    earningsYieldTTM: float = Field(..., description="The earnings yield ttm of the key metrics ttm")
    freeCashFlowYieldTTM: float = Field(..., description="The free cash flow yield ttm of the key metrics ttm")
    capexToOperatingCashFlowTTM: float = Field(..., description="The capex to operating cash flow ttm of the key metrics ttm")
    capexToDepreciationTTM: float = Field(..., description="The capex to depreciation ttm of the key metrics ttm")
    capexToRevenueTTM: float = Field(..., description="The capex to revenue ttm of the key metrics ttm")
    salesGeneralAndAdministrativeToRevenueTTM: float = Field(..., description="The sales general and administrative to revenue ttm of the key metrics ttm")
    researchAndDevelopementToRevenueTTM: float = Field(..., description="The research and development to revenue ttm of the key metrics ttm")
    stockBasedCompensationToRevenueTTM: float = Field(..., description="The stock based compensation to revenue ttm of the key metrics ttm")
    intangiblesToTotalAssetsTTM: float = Field(..., description="The intangibles to total assets ttm of the key metrics ttm")
    averageReceivablesTTM: float = Field(..., description="The average receivables ttm of the key metrics ttm")
    averagePayablesTTM: float = Field(..., description="The average payables ttm of the key metrics ttm")
    averageInventoryTTM: float = Field(..., description="The average inventory ttm of the key metrics ttm")
    daysOfSalesOutstandingTTM: float = Field(..., description="The days of sales outstanding ttm of the key metrics ttm")
    daysOfPayablesOutstandingTTM: float = Field(..., description="The days of payables outstanding ttm of the key metrics ttm")
    daysOfInventoryOutstandingTTM: float = Field(..., description="The days of inventory outstanding ttm of the key metrics ttm")
    operatingCycleTTM: float = Field(..., description="The operating cycle ttm of the key metrics ttm")
    cashConversionCycleTTM: float = Field(..., description="The cash conversion cycle ttm of the key metrics ttm")
    freeCashFlowToEquityTTM: float = Field(..., description="The free cash flow to equity ttm of the key metrics ttm")
    freeCashFlowToFirmTTM: float = Field(..., description="The free cash flow to firm ttm of the key metrics ttm")
    tangibleAssetValueTTM: float = Field(..., description="The tangible asset value ttm of the key metrics ttm")
    netCurrentAssetValueTTM: float = Field(..., description="The net current asset value ttm of the key metrics ttm")

class Ratios(BaseModel):
    symbol: str = Field(..., description="The symbol of the ratios")
    date: str = Field(..., description="The date of the ratios")
    fiscalYear: str = Field(..., description="The fiscal year of the ratios")
    period: str = Field(..., description="The period of the ratios")
    reportedCurrency: str = Field(..., description="The reported currency of the ratios")
    grossProfitMargin: float = Field(..., description="The gross profit margin of the ratios")
    ebitMargin: float = Field(..., description="The ebit margin of the ratios")
    ebitdaMargin: float = Field(..., description="The ebitda margin of the ratios")
    operatingProfitMargin: float = Field(..., description="The operating profit margin of the ratios")
    pretaxProfitMargin: float = Field(..., description="The pretax profit margin of the ratios")
    continuousOperationsProfitMargin: float = Field(..., description="The continuous operations profit margin of the ratios")
    netProfitMargin: float = Field(..., description="The net profit margin of the ratios")
    bottomLineProfitMargin: float = Field(..., description="The bottom line profit margin of the ratios")
    receivablesTurnover: float = Field(..., description="The receivables turnover of the ratios")
    payablesTurnover: float = Field(..., description="The payables turnover of the ratios")
    inventoryTurnover: float = Field(..., description="The inventory turnover of the ratios")
    fixedAssetTurnover: float = Field(..., description="The fixed asset turnover of the ratios")
    assetTurnover: float = Field(..., description="The asset turnover of the ratios")
    currentRatio: float = Field(..., description="The current ratio of the ratios")
    quickRatio: float = Field(..., description="The quick ratio of the ratios")
    solvencyRatio: float = Field(..., description="The solvency ratio of the ratios")
    cashRatio: float = Field(..., description="The cash ratio of the ratios")
    priceToEarningsRatio: float = Field(..., description="The price to earnings ratio of the ratios")
    priceToEarningsGrowthRatio: float = Field(..., description="The price to earnings growth ratio of the ratios")
    forwardPriceToEarningsGrowthRatio: float = Field(..., description="The forward price to earnings growth ratio of the ratios")
    priceToBookRatio: float = Field(..., description="The price to book ratio of the ratios")
    priceToSalesRatio: float = Field(..., description="The price to sales ratio of the ratios")
    priceToFreeCashFlowRatio: float = Field(..., description="The price to free cash flow ratio of the ratios")
    priceToOperatingCashFlowRatio: float = Field(..., description="The price to operating cash flow ratio of the ratios")
    debtToAssetsRatio: float = Field(..., description="The debt to assets ratio of the ratios")
    debtToEquityRatio: float = Field(..., description="The debt to equity ratio of the ratios")
    debtToCapitalRatio: float = Field(..., description="The debt to capital ratio of the ratios")
    longTermDebtToCapitalRatio: float = Field(..., description="The long term debt to capital ratio of the ratios")
    financialLeverageRatio: float = Field(..., description="The financial leverage ratio of the ratios")
    workingCapitalTurnoverRatio: float = Field(..., description="The working capital turnover ratio of the ratios")
    operatingCashFlowRatio: float = Field(..., description="The operating cash flow ratio of the ratios")
    operatingCashFlowSalesRatio: float = Field(..., description="The operating cash flow sales ratio of the ratios")
    freeCashFlowOperatingCashFlowRatio: float = Field(..., description="The free cash flow operating cash flow ratio of the ratios")
    debtServiceCoverageRatio: float = Field(..., description="The debt service coverage ratio of the ratios")
    interestCoverageRatio: float = Field(..., description="The interest coverage ratio of the ratios")
    shortTermOperatingCashFlowCoverageRatio: float = Field(..., description="The short term operating cash flow coverage ratio of the ratios")
    operatingCashFlowCoverageRatio: float = Field(..., description="The operating cash flow coverage ratio of the ratios")
    capitalExpenditureCoverageRatio: float = Field(..., description="The capital expenditure coverage ratio of the ratios")
    dividendPaidAndCapexCoverageRatio: float = Field(..., description="The dividend paid and capex coverage ratio of the ratios")
    dividendPayoutRatio: float = Field(..., description="The dividend payout ratio of the ratios")
    dividendYield: float = Field(..., description="The dividend yield of the ratios")
    dividendYieldPercentage: float = Field(..., description="The dividend yield percentage of the ratios")
    revenuePerShare: float = Field(..., description="The revenue per share of the ratios")
    netIncomePerShare: float = Field(..., description="The net income per share of the ratios")
    interestDebtPerShare: float = Field(..., description="The interest debt per share of the ratios")
    cashPerShare: float = Field(..., description="The cash per share of the ratios")
    bookValuePerShare: float = Field(..., description="The book value per share of the ratios")
    tangibleBookValuePerShare: float = Field(..., description="The tangible book value per share of the ratios")
    shareholdersEquityPerShare: float = Field(..., description="The shareholders equity per share of the ratios")
    operatingCashFlowPerShare: float = Field(..., description="The operating cash flow per share of the ratios")
    capexPerShare: float = Field(..., description="The capex per share of the ratios")
    freeCashFlowPerShare: float = Field(..., description="The free cash flow per share of the ratios")
    netIncomePerEBT: float = Field(..., description="The net income per ebt of the ratios")
    ebtPerEbit: float = Field(..., description="The ebt per ebit of the ratios")
    priceToFairValue: float = Field(..., description="The price to fair value of the ratios")
    debtToMarketCap: float = Field(..., description="The debt to market cap of the ratios")
    effectiveTaxRate: float = Field(..., description="The effective tax rate of the ratios")
    enterpriseValueMultiple: float = Field(..., description="The enterprise value multiple of the ratios")

class RatiosTTM(BaseModel):
    symbol: str = Field(..., description="The symbol of the ratios ttm")
    grossProfitMarginTTM: float = Field(..., description="The gross profit margin ttm of the ratios ttm")
    ebitMarginTTM: float = Field(..., description="The ebit margin ttm of the ratios ttm")
    ebitdaMarginTTM: float = Field(..., description="The ebitda margin ttm of the ratios ttm")
    operatingProfitMarginTTM: float = Field(..., description="The operating profit margin ttm of the ratios ttm")
    pretaxProfitMarginTTM: float = Field(..., description="The pretax profit margin ttm of the ratios ttm")
    continuousOperationsProfitMarginTTM: float = Field(..., description="The continuous operations profit margin ttm of the ratios ttm")
    netProfitMarginTTM: float = Field(..., description="The net profit margin ttm of the ratios ttm")
    bottomLineProfitMarginTTM: float = Field(..., description="The bottom line profit margin ttm of the ratios ttm")
    receivablesTurnoverTTM: float = Field(..., description="The receivables turnover ttm of the ratios ttm")
    payablesTurnoverTTM: float = Field(..., description="The payables turnover ttm of the ratios ttm")
    inventoryTurnoverTTM: float = Field(..., description="The inventory turnover ttm of the ratios ttm")
    fixedAssetTurnoverTTM: float = Field(..., description="The fixed asset turnover ttm of the ratios ttm")
    assetTurnoverTTM: float = Field(..., description="The asset turnover ttm of the ratios ttm")
    currentRatioTTM: float = Field(..., description="The current ratio ttm of the ratios ttm")
    quickRatioTTM: float = Field(..., description="The quick ratio ttm of the ratios ttm")
    solvencyRatioTTM: float = Field(..., description="The solvency ratio ttm of the ratios ttm")
    cashRatioTTM: float = Field(..., description="The cash ratio ttm of the ratios ttm")
    priceToEarningsRatioTTM: float = Field(..., description="The price to earnings ratio ttm of the ratios ttm")
    priceToEarningsGrowthRatioTTM: float = Field(..., description="The price to earnings growth ratio ttm of the ratios ttm")
    forwardPriceToEarningsGrowthRatioTTM: float = Field(..., description="The forward price to earnings growth ratio ttm of the ratios ttm")
    priceToBookRatioTTM: float = Field(..., description="The price to book ratio ttm of the ratios ttm")
    priceToSalesRatioTTM: float = Field(..., description="The price to sales ratio ttm of the ratios ttm")
    priceToFreeCashFlowRatioTTM: float = Field(..., description="The price to free cash flow ratio ttm of the ratios ttm")
    priceToOperatingCashFlowRatioTTM: float = Field(..., description="The price to operating cash flow ratio ttm of the ratios ttm")
    debtToAssetsRatioTTM: float = Field(..., description="The debt to assets ratio ttm of the ratios ttm")
    debtToEquityRatioTTM: float = Field(..., description="The debt to equity ratio ttm of the ratios ttm")
    debtToCapitalRatioTTM: float = Field(..., description="The debt to capital ratio ttm of the ratios ttm")
    longTermDebtToCapitalRatioTTM: float = Field(..., description="The long term debt to capital ratio ttm of the ratios ttm")
    financialLeverageRatioTTM: float = Field(..., description="The financial leverage ratio ttm of the ratios ttm")
    workingCapitalTurnoverRatioTTM: float = Field(..., description="The working capital turnover ratio ttm of the ratios ttm")
    operatingCashFlowRatioTTM: float = Field(..., description="The operating cash flow ratio ttm of the ratios ttm")
    operatingCashFlowSalesRatioTTM: float = Field(..., description="The operating cash flow sales ratio ttm of the ratios ttm")
    freeCashFlowOperatingCashFlowRatioTTM: float = Field(..., description="The free cash flow operating cash flow ratio ttm of the ratios ttm")
    debtServiceCoverageRatioTTM: float = Field(..., description="The debt service coverage ratio ttm of the ratios ttm")
    interestCoverageRatioTTM: float = Field(..., description="The interest coverage ratio ttm of the ratios ttm")
    shortTermOperatingCashFlowCoverageRatioTTM: float = Field(..., description="The short term operating cash flow coverage ratio ttm of the ratios ttm")
    operatingCashFlowCoverageRatioTTM: float = Field(..., description="The operating cash flow coverage ratio ttm of the ratios ttm")
    capitalExpenditureCoverageRatioTTM: float = Field(..., description="The capital expenditure coverage ratio ttm of the ratios ttm")
    dividendPaidAndCapexCoverageRatioTTM: float = Field(..., description="The dividend paid and capex coverage ratio ttm of the ratios ttm")
    dividendPayoutRatioTTM: float = Field(..., description="The dividend payout ratio ttm of the ratios ttm")
    dividendYieldTTM: float = Field(..., description="The dividend yield ttm of the ratios ttm")
    enterpriseValueTTM: float = Field(..., description="The enterprise value ttm of the ratios ttm")
    revenuePerShareTTM: float = Field(..., description="The revenue per share ttm of the ratios ttm")
    netIncomePerShareTTM: float = Field(..., description="The net income per share ttm of the ratios ttm")
    interestDebtPerShareTTM: float = Field(..., description="The interest debt per share ttm of the ratios ttm")
    cashPerShareTTM: float = Field(..., description="The cash per share ttm of the ratios ttm")
    bookValuePerShareTTM: float = Field(..., description="The book value per share ttm of the ratios ttm")
    tangibleBookValuePerShareTTM: float = Field(..., description="The tangible book value per share ttm of the ratios ttm")
    shareholdersEquityPerShareTTM: float = Field(..., description="The shareholders equity per share ttm of the ratios ttm")
    operatingCashFlowPerShareTTM: float = Field(..., description="The operating cash flow per share ttm of the ratios ttm")
    capexPerShareTTM: float = Field(..., description="The capex per share ttm of the ratios ttm")
    freeCashFlowPerShareTTM: float = Field(..., description="The free cash flow per share ttm of the ratios ttm")
    netIncomePerEBTTTM: float = Field(..., description="The net income per ebt ttm of the ratios ttm")
    ebtPerEbitTTM: float = Field(..., description="The ebt per ebit ttm of the ratios ttm")
    priceToFairValueTTM: float = Field(..., description="The price to fair value ttm of the ratios ttm")
    debtToMarketCapTTM: float = Field(..., description="The debt to market cap ttm of the ratios ttm")
    effectiveTaxRateTTM: float = Field(..., description="The effective tax rate ttm of the ratios ttm")
    enterpriseValueMultipleTTM: float = Field(..., description="The enterprise value multiple ttm of the ratios ttm")

class FinancialScores(BaseModel):
    symbol: str = Field(..., description="The symbol of the financial scores")
    reportedCurrency: str = Field(..., description="The reported currency of the financial scores")
    altmanZScore: float = Field(..., description="The altman z score of the financial scores")
    piotroskiScore: int = Field(..., description="The piotroski score of the financial scores")
    workingCapital: float = Field(..., description="The working capital of the financial scores")
    totalAssets: float = Field(..., description="The total assets of the financial scores")
    retainedEarnings: float = Field(..., description="The retained earnings of the financial scores")
    ebit: float = Field(..., description="The ebit of the financial scores")
    marketCap: float = Field(..., description="The market cap of the financial scores")
    totalLiabilities: float = Field(..., description="The total liabilities of the financial scores")
    revenue: float = Field(..., description="The revenue of the financial scores")

class OwnerEarnings(BaseModel):
    symbol: str = Field(..., description="The symbol of the owner earnings")
    reportedCurrency: str = Field(..., description="The reported currency of the owner earnings")
    fiscalYear: str = Field(..., description="The fiscal year of the owner earnings")
    period: str = Field(..., description="The period of the owner earnings")
    date: str = Field(..., description="The date of the owner earnings")
    averagePPE: float = Field(..., description="The average ppe of the owner earnings")
    maintenanceCapex: float = Field(..., description="The maintenance capex of the owner earnings")
    ownersEarnings: float = Field(..., description="The owners earnings of the owner earnings")
    growthCapex: float = Field(..., description="The growth capex of the owner earnings")
    ownersEarningsPerShare: float = Field(..., description="The owners earnings per share of the owner earnings")

class EnterpriseValues(BaseModel):
    symbol: str = Field(..., description="The symbol of the enterprise values")
    date: str = Field(..., description="The date of the enterprise values")
    stockPrice: float = Field(..., description="The stock price of the enterprise values")
    numberOfShares: float = Field(..., description="The number of shares of the enterprise values")
    marketCapitalization: float = Field(..., description="The market capitalization of the enterprise values")
    minusCashAndCashEquivalents: float = Field(..., description="The minus cash and cash equivalents of the enterprise values")
    addTotalDebt: float = Field(..., description="The add total debt of the enterprise values")
    enterpriseValue: float = Field(..., description="The enterprise value of the enterprise values")